Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenloader/intern/blend_validate.c')
-rw-r--r--source/blender/blenloader/intern/blend_validate.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenloader/intern/blend_validate.c b/source/blender/blenloader/intern/blend_validate.c
index 323ecedb971..7fe06d90ac1 100644
--- a/source/blender/blenloader/intern/blend_validate.c
+++ b/source/blender/blenloader/intern/blend_validate.c
@@ -18,7 +18,7 @@
* \ingroup blenloader
*
* Utils to check/validate a Main is in sane state,
* only checks relations between datablocks and libraries for now.
*
* \note Does not *fix* anything, only reports found errors.
*/
@@ -77,7 +77,7 @@ bool BLO_main_validate_libraries(Main *bmain, ReportList *reports)
for (Main *curmain = bmain->next; curmain != NULL; curmain = curmain->next) {
Library *curlib = curmain->curlib;
if (curlib == NULL) {
- BKE_report(reports, RPT_ERROR, "Library database with NULL library datablock!");
+ BKE_report(reports, RPT_ERROR, "Library database with NULL library data-block!");
continue;
}
@@ -18,7 +18,7 @@
*
* Utils to check/validate a Main is in sane state,
- * only checks relations between datablocks and libraries for now.
+ * only checks relations between data-blocks and libraries for now.
*
* \note Does not *fix* anything, only reports found errors.